@@ -4,8 +4,11 @@ from __future__ import unicode_literals
 
 
 class Parser(object):
-    def __init__(self, options):
-        self.options = options
+    accepts = ()
+    
+    
+    def __init__(self, options = None):
+        self.options = options if options is not None else {}
         
         self.setup()
     
@@ -17,21 +20,21 @@ class Parser(object):
         pass
 
 class Renderer(object):
-    def __init__(self, path, options, globals_ = {}):
+    def __init__(self, path, options = None, globals_ = None):
         self.path = path
-        self.options = options
-        self.globals = globals_
+        self.options = options if options is not None else {}
+        self.globals = globals_ if globals_ is not None else {}
         
         self.setup()
     
     
-    def from_string(self, source, vars_ = {}):
+    def from_string(self, string, data = None):
         raise NotImplementedError('A renderer must implement from_string.')
     
     def register(self, key, value):
         raise NotImplementedError('A renderer must implement register.')
     
-    def render(self, template, vars_ = {}):
+    def render(self, template, data = None):
         raise NotImplementedError('A renderer must implement render.')
     
     def setup(self):
