@@ -11,11 +11,10 @@ from re import sub
 
 from jinja2 import Environment, FileSystemLoader, PrefixLoader
 from jinja2.exceptions import TemplateNotFound
-from jinja2.utils import internalcode
 
 from mynt.base import Renderer as _Renderer
 from mynt.exceptions import RendererException
-from mynt.utils import absurl, normpath
+from mynt.utils import normpath, Url
 
 
 class _PrefixLoader(PrefixLoader):
@@ -41,14 +40,6 @@ class _PrefixLoader(PrefixLoader):
             name = name.replace(op.sep, '/')
         
         return loader, name
-    
-    @internalcode
-    def load(self, environment, name, globals=None):
-        loader, local_name = self.get_loader(name)
-        try:
-            return loader.load(environment, local_name, globals)
-        except TemplateNotFound:
-            raise TemplateNotFound(name)
 
 
 class Renderer(_Renderer):
@@ -68,7 +59,7 @@ class Renderer(_Renderer):
         return datetime.utcfromtimestamp(ts).strftime(format).decode('utf-8')
     
     def _get_asset(self, asset):
-        return absurl(self.globals['site']['base_url'], self.globals['site']['assets_url'], asset)
+        return Url.join(self.globals['site']['base_url'], self.globals['site']['assets_url'], asset)
     
     def _get_url(self, url = '', absolute = False):
         parts = [self.globals['site']['base_url'], url]
@@ -80,25 +71,37 @@ class Renderer(_Renderer):
             
             parts.insert(0, domain)
         
-        return absurl(*parts)
+        return Url.join(*parts)
+    
+    def _items(self, dict_):
+        return dict_.iteritems()
+    
+    def _values(self, dict_):
+        return dict_.itervalues()
     
     
-    def from_string(self, source, vars_ = {}):
-        template = self.environment.from_string(source)
+    def from_string(self, string, data = None):
+        if data is None:
+            data = {}
         
-        return template.render(**vars_)
+        template = self.environment.from_string(string)
+        
+        return template.render(**data)
     
-    def register(self, vars_):
-        self.globals.update(vars_)
-        self.environment.globals.update(vars_)
+    def register(self, data):
+        self.globals.update(data)
+        self.environment.globals.update(data)
     
-    def render(self, template, vars_ = {}):
+    def render(self, template, data = None):
+        if data is None:
+            data = {}
+        
         try:
             template = self.environment.get_template(template)
         except TemplateNotFound:
             raise RendererException('Template not found.')
         
-        return template.render(**vars_)
+        return template.render(**data)
     
     def setup(self):
         self.config.update(self.options)
@@ -111,6 +114,8 @@ class Renderer(_Renderer):
         
         self.environment.filters['absolutize'] = self._absolutize
         self.environment.filters['date'] = self._date
+        self.environment.filters['items'] = self._items
+        self.environment.filters['values'] = self._values
         
         self.environment.globals.update(self.globals)
         self.environment.globals['get_asset'] = self._get_asset
